@@ -858,9 +858,9 @@ class Utils:
         return result
 
     @classmethod
-    def params_join(cls, params, filters=[]):
+    def params_join(cls, params, filters=None):
 
-        if filters:
+        if filters is not None:
             params = {key: val for key, val in params.items() if key not in filters}
 
         return r'&'.join(f'{key}={val}' for key, val in sorted(params.items(), key=lambda x: x[0]))
