@@ -5,6 +5,8 @@ __author__ = r'wsb310@gmail.com'
 import asyncio
 import aio_pika
 
+from typing import List
+
 from ...extend.base import Utils
 from ...extend.asyncio.pool import ObjectPool
 
@@ -17,23 +19,27 @@ class RabbitMQProducer(aio_pika.RobustConnection):
 
         super().__init__(url, **kwargs)
 
-        self._channel = None
+        self._channel: aio_pika.abc.AbstractRobustChannel = None
 
-        self._lock = asyncio.Lock()
+        self._lock: asyncio.Lock = asyncio.Lock()
 
     @property
-    def current_channel(self):
+    def current_channel(self) -> aio_pika.abc.AbstractRobustChannel:
 
         return self._channel
 
-    async def connect(self, *args, **kwargs):
+    async def connect(
+            self, *,
+            channel_number: int = None, publisher_confirms: bool = True, on_return_raises: bool = False,
+            timeout: aio_pika.abc.TimeoutType = None
+    ):
 
-        await super().connect(*args, **kwargs)
+        await super().connect(timeout)
 
         await self.ready()
 
         if self._channel is None:
-            self._channel = await self.channel()
+            self._channel = await self.channel(channel_number, publisher_confirms, on_return_raises)
 
     async def close(self):
 
@@ -43,20 +49,11 @@ class RabbitMQProducer(aio_pika.RobustConnection):
     async def publish(self, message, routing_key, **kwargs):
 
         async with self._lock:
-            await self._channel.default_exchange.publish(
+            return await self._channel.default_exchange.publish(
                 message if isinstance(message, aio_pika.Message) else aio_pika.Message(message),
                 routing_key, **kwargs
             )
 
-    async def batch_publish(self, messages, routing_key, **kwargs):
-
-        async with self._lock:
-            for message in messages:
-                await self._channel.default_exchange.publish(
-                    message if isinstance(message, aio_pika.Message) else aio_pika.Message(message),
-                    routing_key, **kwargs
-                )
-
 
 class RabbitMQProducerForExchange(RabbitMQProducer):
     """RabbitMQ交换机发布者
@@ -66,14 +63,14 @@ class RabbitMQProducerForExchange(RabbitMQProducer):
 
         super().__init__(url, **kwargs)
 
-        self._exchange = None
+        self._exchange: aio_pika.abc.AbstractExchange = None
 
         self._exchange_name = None
         self._exchange_type = None
         self._exchange_config = None
 
     @property
-    def current_exchange(self):
+    def current_exchange(self) -> aio_pika.abc.AbstractExchange:
 
         return self._exchange
 
@@ -86,9 +83,18 @@ class RabbitMQProducerForExchange(RabbitMQProducer):
         self._exchange_type = exchange_type
         self._exchange_config = exchange_config if exchange_config else {}
 
-    async def connect(self, *args, **kwargs):
+    async def connect(
+            self, *,
+            channel_number: int = None, publisher_confirms: bool = True, on_return_raises: bool = False,
+            timeout: aio_pika.abc.TimeoutType = None
+    ):
 
-        await super().connect(*args, **kwargs)
+        await super().connect(
+            channel_number=channel_number,
+            publisher_confirms=publisher_confirms,
+            on_return_raises=on_return_raises,
+            timeout=timeout
+        )
 
         if self._exchange is None:
             self._exchange = await self._channel.declare_exchange(
@@ -98,20 +104,11 @@ class RabbitMQProducerForExchange(RabbitMQProducer):
     async def publish(self, message, routing_key=r'', **kwargs):
 
         async with self._lock:
-            await self._exchange.publish(
+            return await self._exchange.publish(
                 message if isinstance(message, aio_pika.Message) else aio_pika.Message(message),
                 routing_key, **kwargs
             )
 
-    async def batch_publish(self, messages, routing_key=r'', **kwargs):
-
-        async with self._lock:
-            for message in messages:
-                await self._exchange.publish(
-                    message if isinstance(message, aio_pika.Message) else aio_pika.Message(message),
-                    routing_key, **kwargs
-                )
-
 
 class RabbitMQProducerPool(ObjectPool):
     """RabbitMQ发布者连接池
@@ -123,7 +120,7 @@ class RabbitMQProducerPool(ObjectPool):
 
         self._connection_config = connection_config if connection_config else {}
 
-        self._connections = []
+        self._connections: List[RabbitMQProducer] = []
 
         super().__init__(pool_size)
 
@@ -135,10 +132,18 @@ class RabbitMQProducerPool(ObjectPool):
 
         return connection
 
-    async def connect(self):
+    async def connect(
+            self, *,
+            publisher_confirms: bool = True, on_return_raises: bool = False,
+            timeout: aio_pika.abc.TimeoutType = None
+    ):
 
         for connection in self._connections:
-            await connection.connect()
+            await connection.connect(
+                publisher_confirms=publisher_confirms,
+                on_return_raises=on_return_raises,
+                timeout=timeout,
+            )
 
         Utils.log.info(f'rabbitmq producer pool connected: {self._queue.qsize()}')
 
@@ -150,20 +155,11 @@ class RabbitMQProducerPool(ObjectPool):
     async def publish(self, message, routing_key=r'', **kwargs):
 
         async with self.get() as connection:
-            await connection.publish(
+            return await connection.publish(
                 message if isinstance(message, aio_pika.Message) else aio_pika.Message(message),
                 routing_key, **kwargs
             )
 
-    async def batch_publish(self, messages, routing_key=r'', **kwargs):
-
-        async with self.get() as connection:
-            for message in messages:
-                await connection.publish(
-                    message if isinstance(message, aio_pika.Message) else aio_pika.Message(message),
-                    routing_key, **kwargs
-                )
-
 
 class RabbitMQProducerForExchangePool(RabbitMQProducerPool):
     """RabbitMQ交换机发布者连接池
